Merge branch 'release_0.84.00' into privatestaging

Conflicts:
	include/hcc_detail/hip_runtime.h
	src/hip_hcc.cpp


[ROCm/clr commit: 02e6fc27f4]
Cette révision appartient à :
Maneesh Gupta
2016-04-22 10:55:58 +05:30
révision 03014e8a1d
220 fichiers modifiés avec 5545 ajouts et 11003 suppressions
+1 -1
Voir le fichier
@@ -1,6 +1,6 @@
#ifndef HCC_ACC_H
#define HCC_ACC_H
#include "hip_runtime_api.h"
#include "hip/hip_runtime_api.h"
#if __cplusplus
#ifdef __HCC__
+2 -2
Voir le fichier
@@ -21,8 +21,8 @@ THE SOFTWARE.
#define HIP_HCC_H
#include <hc.hpp>
#include "hcc_detail/hip_util.h"
#include "hcc_detail/staging_buffer.h"
#include "hip/hcc_detail/hip_util.h"
#include "hip/hcc_detail/staging_buffer.h"
#if defined(__HCC__) && (__hcc_workweek__ < 1502)
+3 -2
Voir le fichier
@@ -21,8 +21,9 @@ THE SOFTWARE.
#define HIP_LDG_H
#if __HCC__
#include"hip_vector_types.h"
#include"host_defines.h"
#include"hip/hip_vector_types.h"
#include"hip/hcc_detail/host_defines.h"
__device__ char __ldg(const char* );
__device__ char1 __ldg(const char1* );
+5 -5
Voir le fichier
@@ -40,8 +40,8 @@ THE SOFTWARE.
#define CUDA_SUCCESS hipSuccess
#include <hip_runtime_api.h>
//#include "hcc_detail/hip_hcc.h"
#include <hip/hip_runtime_api.h>
//#include "hip/hcc_detail/hip_hcc.h"
//---
// Remainder of this file only compiles with HCC
#ifdef __HCC__
@@ -55,10 +55,10 @@ extern int HIP_TRACE_API;
//typedef grid_launch_parm hipLaunchParm ;
#define hipLaunchParm grid_launch_parm
#ifdef __cplusplus
#include <hcc_detail/hip_texture.h>
#include <hcc_detail/hip_ldg.h>
#include <hip/hcc_detail/hip_texture.h>
#include <hip/hcc_detail/hip_ldg.h>
#endif
#include <hcc_detail/host_defines.h>
#include <hip/hcc_detail/host_defines.h>
// TODO-HCC remove old definitions ; ~1602 hcc supports __HCC_ACCELERATOR__ define.
#if defined (__KALMAR_ACCELERATOR__) && !defined (__HCC_ACCELERATOR__)
#define __HCC_ACCELERATOR__ __KALMAR_ACCELERATOR__
+4 -4
Voir le fichier
@@ -30,11 +30,11 @@ THE SOFTWARE.
#include <stdint.h>
#include <stddef.h>
#include <hcc_detail/host_defines.h>
#include <hip_runtime_api.h>
//#include "hip_hcc.h"
#include <hip/hcc_detail/host_defines.h>
#include <hip/hip_runtime_api.h>
//#include "hip/hip_hcc.h"
#if defined (__HCC__) && (__hcc_workweek__ < 16074)
#if defined (__HCC__) && (__hcc_workweek__ < 16155)
#error("This version of HIP requires a newer version of HCC.");
#endif
+1 -1
Voir le fichier
@@ -32,7 +32,7 @@ THE SOFTWARE.
#include <limits.h>
#include <hip_runtime.h>
#include <hip/hip_runtime.h>
//----
//Texture - TODO - likely need to move this to a separate file only included with kernel compilation.
+1 -1
Voir le fichier
@@ -116,7 +116,7 @@ typedef hc::short_vector::double3 double3;
typedef hc::short_vector::double4 double4;
#if __HCC__
#include"host_defines.h"
#include"hip/hcc_detail/host_defines.h"
#define __HIP_DEVICE__ __device__ __host__
#else
#define __HIP_DEVICE__
+5 -5
Voir le fichier
@@ -48,17 +48,17 @@ THE SOFTWARE.
#endif
#include <hip_common.h>
#include <hip/hip_common.h>
#if defined(__HIP_PLATFORM_HCC__) && !defined (__HIP_PLATFORM_NVCC__)
#include <hcc_detail/hip_runtime.h>
#include <hip/hcc_detail/hip_runtime.h>
#elif defined(__HIP_PLATFORM_NVCC__) && !defined (__HIP_PLATFORM_HCC__)
#include <nvcc_detail/hip_runtime.h>
#include <hip/nvcc_detail/hip_runtime.h>
#else
#error("Must define exactly one of __HIP_PLATFORM_HCC__ or __HIP_PLATFORM_NVCC__");
#endif
#include <hip_runtime_api.h>
#include <hip_vector_types.h>
#include <hip/hip_runtime_api.h>
#include <hip/hip_vector_types.h>
+3 -3
Voir le fichier
@@ -30,7 +30,7 @@ THE SOFTWARE.
#include <string.h> // for getDeviceProp
#include <hip_common.h>
#include <hip/hip_common.h>
typedef struct {
// 32-bit Atomics
@@ -202,9 +202,9 @@ typedef enum hipDeviceAttribute_t {
*/
#if defined(__HIP_PLATFORM_HCC__) && !defined (__HIP_PLATFORM_NVCC__)
#include "hcc_detail/hip_runtime_api.h"
#include "hip/hcc_detail/hip_runtime_api.h"
#elif defined(__HIP_PLATFORM_NVCC__) && !defined (__HIP_PLATFORM_HCC__)
#include "nvcc_detail/hip_runtime_api.h"
#include "hip/nvcc_detail/hip_runtime_api.h"
#else
#error("Must define exactly one of __HIP_PLATFORM_HCC__ or __HIP_PLATFORM_NVCC__");
#endif
+2 -2
Voir le fichier
@@ -23,12 +23,12 @@ THE SOFTWARE.
#pragma once
#include <hip_common.h>
#include <hip/hip_common.h>
#if defined(__HIP_PLATFORM_HCC__) && !defined (__HIP_PLATFORM_NVCC__)
#if __cplusplus
#include <hcc_detail/hip_vector_types.h>
#include <hip/hcc_detail/hip_vector_types.h>
#endif
#elif defined(__HIP_PLATFORM_NVCC__) && !defined (__HIP_PLATFORM_HCC__)
#include <vector_types.h>
+1 -1
Voir le fichier
@@ -23,7 +23,7 @@ THE SOFTWARE.
#include <cuda_runtime.h>
#include <hip_runtime_api.h>
#include <hip/hip_runtime_api.h>
#define HIP_KERNEL_NAME(...) __VA_ARGS__